@@ -34,7 +34,7 @@
 
 using namespace icinga;
 
-#define SCHEMA_VERSION "1.11.6"
+#define SCHEMA_VERSION "1.11.7"
 
 REGISTER_TYPE(IdoPgsqlConnection);
 
@@ -44,7 +44,7 @@ Value IdoPgsqlConnection::StatsFunc(Dictionary::Ptr& status, Dictionary::Ptr& pe
 {
 	Dictionary::Ptr nodes = make_shared<Dictionary>();
 
-	BOOST_FOREACH(const IdoPgsqlConnection::Ptr& idopgsqlconnection, DynamicType::GetObjects<IdoPgsqlConnection>()) {
+	BOOST_FOREACH(const IdoPgsqlConnection::Ptr& idopgsqlconnection, DynamicType::GetObjectsByType<IdoPgsqlConnection>()) {
 		size_t items = idopgsqlconnection->m_QueryQueue.GetLength();
 
 		Dictionary::Ptr stats = make_shared<Dictionary>();
@@ -212,15 +212,15 @@ void IdoPgsqlConnection::Reconnect(void)
 		String dbVersionName = "idoutils";
 		IdoPgsqlResult result = Query("SELECT version FROM " + GetTablePrefix() + "dbversion WHERE name=E'" + Escape(dbVersionName) + "'");
 
-		Dictionary::Ptr version_row = FetchRow(result, 0);
+		Dictionary::Ptr row = FetchRow(result, 0);
 
-		if (!version_row) {
+		if (!row) {
 			Log(LogCritical, "IdoPgsqlConnection", "Schema does not provide any valid version! Verify your schema installation.");
 
 			Application::Exit(EXIT_FAILURE);
 		}
 
-		String version = version_row->Get("version");
+		String version = row->Get("version");
 
 		if (Utility::CompareVersion(SCHEMA_VERSION, version) < 0) {
 			Log(LogCritical, "IdoPgsqlConnection", "Schema version '" + version + "' does not match the required version '" +
@@ -232,8 +232,7 @@ void IdoPgsqlConnection::Reconnect(void)
 		String instanceName = GetInstanceName();
 
 		result = Query("SELECT instance_id FROM " + GetTablePrefix() + "instances WHERE instance_name = E'" + Escape(instanceName) + "'");
-
-		Dictionary::Ptr row = FetchRow(result, 0);
+		row = FetchRow(result, 0);
 
 		if (!row) {
 			Query("INSERT INTO " + GetTablePrefix() + "instances (instance_name, instance_description) VALUES (E'" + Escape(instanceName) + "', E'" + Escape(GetInstanceDescription()) + "')");
@@ -242,6 +241,58 @@ void IdoPgsqlConnection::Reconnect(void)
 			m_InstanceID = DbReference(row->Get("instance_id"));
 		}
 
+		Endpoint::Ptr my_endpoint = Endpoint::GetLocalEndpoint();
+
+		/* we have an endpoint in a cluster setup, so decide if we can proceed here */
+		if (my_endpoint && GetHAMode() == HARunOnce) {
+			/* get the current endpoint writing to programstatus table */
+			result = Query("SELECT UNIX_TIMESTAMP(status_update_time) AS status_update_time, endpoint_name FROM " +
+			    GetTablePrefix() + "programstatus WHERE instance_id = " + Convert::ToString(m_InstanceID));
+			row = FetchRow(result, 0);
+
+			String endpoint_name;
+
+			if (row)
+				endpoint_name = row->Get("endpoint_name");
+			else
+				Log(LogNotice, "IdoPgsqlConnection", "Empty program status table");
+
+			/* if we did not write into the database earlier, another instance is active */
+			if (endpoint_name != my_endpoint->GetName()) {
+				double status_update_time;
+
+				if (row)
+					status_update_time = row->Get("status_update_time");
+				else
+					status_update_time = 0;
+
+				double status_update_age = Utility::GetTime() - status_update_time;
+
+				Log(LogNotice, "IdoPgsqlConnection", "Last update by '" +
+				    endpoint_name + "' was " + Convert::ToString(status_update_age) + "s ago.");
+
+				if (status_update_age < GetFailoverTimeout()) {
+					PQfinish(m_Connection);
+					m_Connection = NULL;
+
+					return;
+				}
+
+				/* activate the IDO only, if we're authoritative in this zone */
+				if (IsPaused()) {
+					Log(LogNotice, "IdoPgsqlConnection", "Local endpoint '" +
+					    my_endpoint->GetName() + "' is not authoritative, bailing out.");
+
+					PQfinish(m_Connection);
+					m_Connection = NULL;
+
+					return;
+				}
+			}
+
+			Log(LogNotice, "IdoPgsqlConnection", "Enabling IDO connection.");
+		}
+
 		std::ostringstream msgbuf;
 		msgbuf << "pgSQL IDO instance id: " << static_cast<long>(m_InstanceID) << " (schema version: '" + version + "')";
 		Log(LogInformation, "IdoPgsqlConnection", msgbuf.str());
@@ -312,16 +363,18 @@ IdoPgsqlResult IdoPgsqlConnection::Query(const String& query)
 
 		BOOST_THROW_EXCEPTION(
 		    database_error()
-		        << errinfo_message(message)
-		        << errinfo_database_query(query)
+			<< errinfo_message(message)
+			<< errinfo_database_query(query)
 		);
 	}
 
 	char *rowCount = PQcmdTuples(result);
 	m_AffectedRows = atoi(rowCount);
 
-	if (PQresultStatus(result) == PGRES_COMMAND_OK)
+	if (PQresultStatus(result) == PGRES_COMMAND_OK) {
+		PQclear(result);
 		return IdoPgsqlResult();
+	}
 
 	if (PQresultStatus(result) != PGRES_TUPLES_OK) {
 		String message = PQresultErrorMessage(result);
@@ -333,8 +386,8 @@ IdoPgsqlResult IdoPgsqlConnection::Query(const String& query)
 
 		BOOST_THROW_EXCEPTION(
 		    database_error()
-		        << errinfo_message(message)
-		        << errinfo_database_query(query)
+			<< errinfo_message(message)
+			<< errinfo_database_query(query)
 		);
 	}
 
