@@ -145,7 +145,7 @@ String ServicesTable::GetPrefix(void) const
 
 void ServicesTable::FetchRows(const AddRowFunction& addRowFn)
 {
-	BOOST_FOREACH(const Service::Ptr& service, DynamicType::GetObjects<Service>()) {
+	BOOST_FOREACH(const Service::Ptr& service, DynamicType::GetObjectsByType<Service>()) {
 		addRowFn(service);
 	}
 }
@@ -519,7 +519,7 @@ Value ServicesTable::NoMoreNotificationsAccessor(const Value& row)
 	if (!service)
 		return Empty;
 
-        return CompatUtility::GetCheckableNoMoreNotifications(service);
+	return CompatUtility::GetCheckableNoMoreNotifications(service);
 }
 
 Value ServicesTable::LastTimeOkAccessor(const Value& row)
