@@ -40,7 +40,7 @@ static void OpenSSLLockingCallback(int mode, int type, const char *, int)
 static unsigned long OpenSSLIDCallback(void)
 {
 #ifdef _WIN32
-	return reinterpret_cast<unsigned long>(GetCurrentThreadId());
+	return (unsigned long)GetCurrentThreadId();
 #else /* _WIN32 */
 	return (unsigned long)pthread_self();
 #endif /* _WIN32 */
