@@ -35,9 +35,9 @@
 #	include <pthread_np.h>
 #endif /* __FreeBSD__ */
 
-#ifndef _MSC_VER
+#ifdef HAVE_CXXABI_H
 #	include <cxxabi.h>
-#endif /* _MSC_VER */
+#endif /* HAVE_CXXABI_H */
 
 using namespace icinga;
 
@@ -56,7 +56,7 @@ String Utility::DemangleSymbolName(const String& sym)
 {
 	String result = sym;
 
-#ifndef _MSC_VER
+#ifdef HAVE_CXXABI_H
 	int status;
 	char *realname = abi::__cxa_demangle(sym.CStr(), 0, 0, &status);
 
@@ -64,11 +64,13 @@ String Utility::DemangleSymbolName(const String& sym)
 		result = String(realname);
 		free(realname);
 	}
-#else /* _MSC_VER */
+#elif defined(_MSC_VER) /* HAVE_CXXABI_H */
 	CHAR output[256];
 
 	if (UnDecorateSymbolName(sym.CStr(), output, sizeof(output), UNDNAME_COMPLETE) > 0)
 		result = output;
+#else /* _MSC_VER */
+	/* We're pretty much out of options here. */
 #endif /* _MSC_VER */
 
 	return result;
@@ -682,9 +684,9 @@ void Utility::SetNonBlockingSocket(SOCKET s)
 #endif /* _WIN32 */
 }
 
-void Utility::QueueAsyncCallback(const boost::function<void (void)>& callback)
+void Utility::QueueAsyncCallback(const boost::function<void (void)>& callback, SchedulerPolicy policy)
 {
-	Application::GetTP().Post(callback);
+	Application::GetTP().Post(callback, policy);
 }
 
 String Utility::NaturalJoin(const std::vector<String>& tokens)
@@ -705,7 +707,7 @@ String Utility::NaturalJoin(const std::vector<String>& tokens)
 	return result;
 }
 
-String Utility::FormatDuration(int duration)
+String Utility::FormatDuration(double duration)
 {
 	std::vector<String> tokens;
 	String result;
@@ -713,19 +715,19 @@ String Utility::FormatDuration(int duration)
 	if (duration >= 86400) {
 		int days = duration / 86400;
 		tokens.push_back(Convert::ToString(days) + (days != 1 ? " days" : " day"));
-		duration %= 86400;
+		duration = static_cast<int>(duration) % 86400;
 	}
 
 	if (duration >= 3600) {
 		int hours = duration / 3600;
 		tokens.push_back(Convert::ToString(hours) + (hours != 1 ? " hours" : " hour"));
-		duration %= 3600;
+		duration = static_cast<int>(duration) % 3600;
 	}
 
 	if (duration >= 60) {
 		int minutes = duration / 60;
 		tokens.push_back(Convert::ToString(minutes) + (minutes != 1 ? " minutes" : " minute"));
-		duration %= 60;
+		duration = static_cast<int>(duration) % 60;
 	}
 
 	if (duration >= 1) {
@@ -734,7 +736,7 @@ String Utility::FormatDuration(int duration)
 	}
 
 	if (tokens.size() == 0) {
-		int milliseconds = floor(duration * 1000);
+		int milliseconds = std::floor(duration * 1000);
 		if (milliseconds >= 1)
 			tokens.push_back(Convert::ToString(milliseconds) + (milliseconds != 1 ? " milliseconds" : " millisecond"));
 		else
@@ -777,23 +779,22 @@ String Utility::FormatErrorNumber(int code) {
 	std::ostringstream msgbuf;
 
 #ifdef _WIN32
-        char *message;
-        String result = "Unknown error.";
+	char *message;
+	String result = "Unknown error.";
 
-        DWORD rc = FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER |
-                FORMAT_MESSAGE_FROM_SYSTEM, NULL, code, 0, (char *)&message,
-                0, NULL);
+	DWORD rc = FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER |
+		FORMAT_MESSAGE_FROM_SYSTEM, NULL, code, 0, (char *)&message,
+		0, NULL);
 
-        if (rc != 0) {
-                result = String(message);
-                LocalFree(message);
+	if (rc != 0) {
+		result = String(message);
+		LocalFree(message);
 
-                /* remove trailing new-line characters */
-                boost::algorithm::trim_right(result);
-        }
+		/* remove trailing new-line characters */
+		boost::algorithm::trim_right(result);
+	}
 
-        msgbuf << code << ", \"" << result << "\"";
-        return tmp.str();
+	msgbuf << code << ", \"" << result << "\"";
 #else
 	msgbuf << strerror(code);
 #endif
