@@ -44,6 +44,15 @@ REGISTER_APIFUNCTION(SetEnableActiveChecks, event, &ApiEvents::EnableActiveCheck
 REGISTER_APIFUNCTION(SetEnablePassiveChecks, event, &ApiEvents::EnablePassiveChecksChangedAPIHandler);
 REGISTER_APIFUNCTION(SetEnableNotifications, event, &ApiEvents::EnableNotificationsChangedAPIHandler);
 REGISTER_APIFUNCTION(SetEnableFlapping, event, &ApiEvents::EnableFlappingChangedAPIHandler);
+REGISTER_APIFUNCTION(SetEnableEventHandler, event, &ApiEvents::EnableEventHandlerChangedAPIHandler);
+REGISTER_APIFUNCTION(SetEnablePerfdata, event, &ApiEvents::EnablePerfdataChangedAPIHandler);
+REGISTER_APIFUNCTION(SetCheckInterval, event, &ApiEvents::CheckIntervalChangedAPIHandler);
+REGISTER_APIFUNCTION(SetRetryInterval, event, &ApiEvents::RetryIntervalChangedAPIHandler);
+REGISTER_APIFUNCTION(SetMaxCheckAttempts, event, &ApiEvents::MaxCheckAttemptsChangedAPIHandler);
+REGISTER_APIFUNCTION(SetEventCommand, event, &ApiEvents::EventCommandChangedAPIHandler);
+REGISTER_APIFUNCTION(SetCheckCommand, event, &ApiEvents::CheckCommandChangedAPIHandler);
+REGISTER_APIFUNCTION(SetCheckPeriod, event, &ApiEvents::CheckPeriodChangedAPIHandler);
+REGISTER_APIFUNCTION(SetVars, event, &ApiEvents::VarsChangedAPIHandler);
 REGISTER_APIFUNCTION(AddComment, event, &ApiEvents::CommentAddedAPIHandler);
 REGISTER_APIFUNCTION(RemoveComment, event, &ApiEvents::CommentRemovedAPIHandler);
 REGISTER_APIFUNCTION(AddDowntime, event, &ApiEvents::DowntimeAddedAPIHandler);
@@ -65,6 +74,15 @@ void ApiEvents::StaticInitialize(void)
 	Checkable::OnEnablePassiveChecksChanged.connect(&ApiEvents::EnablePassiveChecksChangedHandler);
 	Checkable::OnEnableNotificationsChanged.connect(&ApiEvents::EnableNotificationsChangedHandler);
 	Checkable::OnEnableFlappingChanged.connect(&ApiEvents::EnableFlappingChangedHandler);
+	Checkable::OnEnableEventHandlerChanged.connect(&ApiEvents::EnableEventHandlerChangedHandler);
+	Checkable::OnEnablePerfdataChanged.connect(&ApiEvents::EnablePerfdataChangedHandler);
+	Checkable::OnCheckIntervalChanged.connect(&ApiEvents::CheckIntervalChangedHandler);
+	Checkable::OnRetryIntervalChanged.connect(&ApiEvents::RetryIntervalChangedHandler);
+	Checkable::OnMaxCheckAttemptsChanged.connect(&ApiEvents::MaxCheckAttemptsChangedHandler);
+	Checkable::OnEventCommandChanged.connect(&ApiEvents::EventCommandChangedHandler);
+	Checkable::OnCheckCommandChanged.connect(&ApiEvents::CheckCommandChangedHandler);
+	Checkable::OnCheckPeriodChanged.connect(&ApiEvents::CheckPeriodChangedHandler);
+	Checkable::OnVarsChanged.connect(&ApiEvents::VarsChangedHandler);
 	Checkable::OnCommentAdded.connect(&ApiEvents::CommentAddedHandler);
 	Checkable::OnCommentRemoved.connect(&ApiEvents::CommentRemovedHandler);
 	Checkable::OnDowntimeAdded.connect(&ApiEvents::DowntimeAddedHandler);
@@ -95,7 +113,7 @@ void ApiEvents::CheckResultHandler(const Checkable::Ptr& checkable, const CheckR
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("cr", Serialize(cr));
@@ -114,7 +132,7 @@ Value ApiEvents::CheckResultAPIHandler(const MessageOrigin& origin, const Dictio
 
 	CheckResult::Ptr cr = Deserialize(crv, true);
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -149,7 +167,7 @@ void ApiEvents::NextCheckChangedHandler(const Checkable::Ptr& checkable, double
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("next_check", nextCheck);
@@ -167,7 +185,7 @@ Value ApiEvents::NextCheckChangedAPIHandler(const MessageOrigin& origin, const D
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -239,7 +257,7 @@ void ApiEvents::ForceNextCheckChangedHandler(const Checkable::Ptr& checkable, bo
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("forced", forced);
@@ -257,7 +275,7 @@ Value ApiEvents::ForceNextCheckChangedAPIHandler(const MessageOrigin& origin, co
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -292,7 +310,7 @@ void ApiEvents::ForceNextNotificationChangedHandler(const Checkable::Ptr& checka
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("forced", forced);
@@ -310,7 +328,7 @@ Value ApiEvents::ForceNextNotificationChangedAPIHandler(const MessageOrigin& ori
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -345,7 +363,7 @@ void ApiEvents::EnableActiveChecksChangedHandler(const Checkable::Ptr& checkable
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("enabled", enabled);
@@ -363,7 +381,7 @@ Value ApiEvents::EnableActiveChecksChangedAPIHandler(const MessageOrigin& origin
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -398,7 +416,7 @@ void ApiEvents::EnablePassiveChecksChangedHandler(const Checkable::Ptr& checkabl
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("enabled", enabled);
@@ -416,7 +434,7 @@ Value ApiEvents::EnablePassiveChecksChangedAPIHandler(const MessageOrigin& origi
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -451,7 +469,7 @@ void ApiEvents::EnableNotificationsChangedHandler(const Checkable::Ptr& checkabl
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("enabled", enabled);
@@ -469,7 +487,7 @@ Value ApiEvents::EnableNotificationsChangedAPIHandler(const MessageOrigin& origi
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -504,7 +522,7 @@ void ApiEvents::EnableFlappingChangedHandler(const Checkable::Ptr& checkable, bo
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("enabled", enabled);
@@ -522,7 +540,7 @@ Value ApiEvents::EnableFlappingChangedAPIHandler(const MessageOrigin& origin, co
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -545,6 +563,504 @@ Value ApiEvents::EnableFlappingChangedAPIHandler(const MessageOrigin& origin, co
 	return Empty;
 }
 
+void ApiEvents::EnableEventHandlerChangedHandler(const Checkable::Ptr& checkable, bool enabled, const MessageOrigin& origin)
+{
+	ApiListener::Ptr listener = ApiListener::GetInstance();
+
+	if (!listener)
+		return;
+
+	Host::Ptr host;
+	Service::Ptr service;
+	tie(host, service) = GetHostService(checkable);
+
+	Dictionary::Ptr params = make_shared<Dictionary>();
+	params->Set("host", host->GetName());
+	if (service)
+		params->Set("service", service->GetShortName());
+	params->Set("enabled", enabled);
+
+	Dictionary::Ptr message = make_shared<Dictionary>();
+	message->Set("jsonrpc", "2.0");
+	message->Set("method", "event::SetEnableEventHandler");
+	message->Set("params", params);
+
+	listener->RelayMessage(origin, checkable, message, true);
+}
+
+Value ApiEvents::EnableEventHandlerChangedAPIHandler(const MessageOrigin& origin, const Dictionary::Ptr& params)
+{
+	if (!params)
+		return Empty;
+
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
+
+	if (!host)
+		return Empty;
+
+	Checkable::Ptr checkable;
+
+	if (params->Contains("service"))
+		checkable = host->GetServiceByShortName(params->Get("service"));
+	else
+		checkable = host;
+
+	if (!checkable)
+		return Empty;
+
+	if (origin.FromZone && !origin.FromZone->CanAccessObject(checkable))
+		return Empty;
+
+	checkable->SetEnableEventHandler(params->Get("enabled"), origin);
+
+	return Empty;
+}
+
+void ApiEvents::EnablePerfdataChangedHandler(const Checkable::Ptr& checkable, bool enabled, const MessageOrigin& origin)
+{
+	ApiListener::Ptr listener = ApiListener::GetInstance();
+
+	if (!listener)
+		return;
+
+	Host::Ptr host;
+	Service::Ptr service;
+	tie(host, service) = GetHostService(checkable);
+
+	Dictionary::Ptr params = make_shared<Dictionary>();
+	params->Set("host", host->GetName());
+	if (service)
+		params->Set("service", service->GetShortName());
+	params->Set("enabled", enabled);
+
+	Dictionary::Ptr message = make_shared<Dictionary>();
+	message->Set("jsonrpc", "2.0");
+	message->Set("method", "event::SetEnablePerfdata");
+	message->Set("params", params);
+
+	listener->RelayMessage(origin, checkable, message, true);
+}
+
+Value ApiEvents::EnablePerfdataChangedAPIHandler(const MessageOrigin& origin, const Dictionary::Ptr& params)
+{
+	if (!params)
+		return Empty;
+
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
+
+	if (!host)
+		return Empty;
+
+	Checkable::Ptr checkable;
+
+	if (params->Contains("service"))
+		checkable = host->GetServiceByShortName(params->Get("service"));
+	else
+		checkable = host;
+
+	if (!checkable)
+		return Empty;
+
+	if (origin.FromZone && !origin.FromZone->CanAccessObject(checkable))
+		return Empty;
+
+	checkable->SetEnablePerfdata(params->Get("enabled"), origin);
+
+	return Empty;
+}
+
+void ApiEvents::CheckIntervalChangedHandler(const Checkable::Ptr& checkable, double interval, const MessageOrigin& origin)
+{
+	ApiListener::Ptr listener = ApiListener::GetInstance();
+
+	if (!listener)
+		return;
+
+	Host::Ptr host;
+	Service::Ptr service;
+	tie(host, service) = GetHostService(checkable);
+
+	Dictionary::Ptr params = make_shared<Dictionary>();
+	params->Set("host", host->GetName());
+	if (service)
+		params->Set("service", service->GetShortName());
+	params->Set("interval", interval);
+
+	Dictionary::Ptr message = make_shared<Dictionary>();
+	message->Set("jsonrpc", "2.0");
+	message->Set("method", "event::SetCheckInterval");
+	message->Set("params", params);
+
+	listener->RelayMessage(origin, checkable, message, true);
+}
+
+Value ApiEvents::CheckIntervalChangedAPIHandler(const MessageOrigin& origin, const Dictionary::Ptr& params)
+{
+	if (!params)
+		return Empty;
+
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
+
+	if (!host)
+		return Empty;
+
+	Checkable::Ptr checkable;
+
+	if (params->Contains("service"))
+		checkable = host->GetServiceByShortName(params->Get("service"));
+	else
+		checkable = host;
+
+	if (!checkable)
+		return Empty;
+
+	if (origin.FromZone && !origin.FromZone->CanAccessObject(checkable))
+		return Empty;
+
+	checkable->SetCheckInterval(params->Get("interval"), origin);
+
+	return Empty;
+}
+
+void ApiEvents::RetryIntervalChangedHandler(const Checkable::Ptr& checkable, double interval, const MessageOrigin& origin)
+{
+	ApiListener::Ptr listener = ApiListener::GetInstance();
+
+	if (!listener)
+		return;
+
+	Host::Ptr host;
+	Service::Ptr service;
+	tie(host, service) = GetHostService(checkable);
+
+	Dictionary::Ptr params = make_shared<Dictionary>();
+	params->Set("host", host->GetName());
+	if (service)
+		params->Set("service", service->GetShortName());
+	params->Set("interval", interval);
+
+	Dictionary::Ptr message = make_shared<Dictionary>();
+	message->Set("jsonrpc", "2.0");
+	message->Set("method", "event::SetRetryInterval");
+	message->Set("params", params);
+
+	listener->RelayMessage(origin, checkable, message, true);
+}
+
+Value ApiEvents::RetryIntervalChangedAPIHandler(const MessageOrigin& origin, const Dictionary::Ptr& params)
+{
+	if (!params)
+		return Empty;
+
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
+
+	if (!host)
+		return Empty;
+
+	Checkable::Ptr checkable;
+
+	if (params->Contains("service"))
+		checkable = host->GetServiceByShortName(params->Get("service"));
+	else
+		checkable = host;
+
+	if (!checkable)
+		return Empty;
+
+	if (origin.FromZone && !origin.FromZone->CanAccessObject(checkable))
+		return Empty;
+
+	checkable->SetRetryInterval(params->Get("interval"), origin);
+
+	return Empty;
+}
+
+void ApiEvents::MaxCheckAttemptsChangedHandler(const Checkable::Ptr& checkable, int attempts, const MessageOrigin& origin)
+{
+	ApiListener::Ptr listener = ApiListener::GetInstance();
+
+	if (!listener)
+		return;
+
+	Host::Ptr host;
+	Service::Ptr service;
+	tie(host, service) = GetHostService(checkable);
+
+	Dictionary::Ptr params = make_shared<Dictionary>();
+	params->Set("host", host->GetName());
+	if (service)
+		params->Set("service", service->GetShortName());
+	params->Set("attempts", attempts);
+
+	Dictionary::Ptr message = make_shared<Dictionary>();
+	message->Set("jsonrpc", "2.0");
+	message->Set("method", "event::SetMaxCheckAttempts");
+	message->Set("params", params);
+
+	listener->RelayMessage(origin, checkable, message, true);
+}
+
+Value ApiEvents::MaxCheckAttemptsChangedAPIHandler(const MessageOrigin& origin, const Dictionary::Ptr& params)
+{
+	if (!params)
+		return Empty;
+
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
+
+	if (!host)
+		return Empty;
+
+	Checkable::Ptr checkable;
+
+	if (params->Contains("service"))
+		checkable = host->GetServiceByShortName(params->Get("service"));
+	else
+		checkable = host;
+
+	if (!checkable)
+		return Empty;
+
+	if (origin.FromZone && !origin.FromZone->CanAccessObject(checkable))
+		return Empty;
+
+	checkable->SetMaxCheckAttempts(params->Get("attempts"), origin);
+
+	return Empty;
+}
+
+void ApiEvents::EventCommandChangedHandler(const Checkable::Ptr& checkable, const EventCommand::Ptr& command, const MessageOrigin& origin)
+{
+	ApiListener::Ptr listener = ApiListener::GetInstance();
+
+	if (!listener)
+		return;
+
+	Host::Ptr host;
+	Service::Ptr service;
+	tie(host, service) = GetHostService(checkable);
+
+	Dictionary::Ptr params = make_shared<Dictionary>();
+	params->Set("host", host->GetName());
+	if (service)
+		params->Set("service", service->GetShortName());
+	params->Set("command", command->GetName());
+
+	Dictionary::Ptr message = make_shared<Dictionary>();
+	message->Set("jsonrpc", "2.0");
+	message->Set("method", "event::SetEventCommand");
+	message->Set("params", params);
+
+	listener->RelayMessage(origin, checkable, message, true);
+}
+
+Value ApiEvents::EventCommandChangedAPIHandler(const MessageOrigin& origin, const Dictionary::Ptr& params)
+{
+	if (!params)
+		return Empty;
+
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
+
+	if (!host)
+		return Empty;
+
+	Checkable::Ptr checkable;
+
+	if (params->Contains("service"))
+		checkable = host->GetServiceByShortName(params->Get("service"));
+	else
+		checkable = host;
+
+	if (!checkable)
+		return Empty;
+
+	EventCommand::Ptr command = EventCommand::GetByName(params->Get("command"));
+
+	if (!command)
+		return Empty;
+
+	if (origin.FromZone && !origin.FromZone->CanAccessObject(checkable))
+		return Empty;
+
+	checkable->SetEventCommand(command, origin);
+
+	return Empty;
+}
+
+void ApiEvents::CheckCommandChangedHandler(const Checkable::Ptr& checkable, const CheckCommand::Ptr& command, const MessageOrigin& origin)
+{
+	ApiListener::Ptr listener = ApiListener::GetInstance();
+
+	if (!listener)
+		return;
+
+	Host::Ptr host;
+	Service::Ptr service;
+	tie(host, service) = GetHostService(checkable);
+
+	Dictionary::Ptr params = make_shared<Dictionary>();
+	params->Set("host", host->GetName());
+	if (service)
+		params->Set("service", service->GetShortName());
+	params->Set("command", command->GetName());
+
+	Dictionary::Ptr message = make_shared<Dictionary>();
+	message->Set("jsonrpc", "2.0");
+	message->Set("method", "event::SetCheckCommand");
+	message->Set("params", params);
+
+	listener->RelayMessage(origin, checkable, message, true);
+}
+
+Value ApiEvents::CheckCommandChangedAPIHandler(const MessageOrigin& origin, const Dictionary::Ptr& params)
+{
+	if (!params)
+		return Empty;
+
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
+
+	if (!host)
+		return Empty;
+
+	Checkable::Ptr checkable;
+
+	if (params->Contains("service"))
+		checkable = host->GetServiceByShortName(params->Get("service"));
+	else
+		checkable = host;
+
+	if (!checkable)
+		return Empty;
+
+	if (origin.FromZone && !origin.FromZone->CanAccessObject(checkable))
+		return Empty;
+
+	CheckCommand::Ptr command = CheckCommand::GetByName(params->Get("command"));
+
+	if (!command)
+		return Empty;
+
+	checkable->SetCheckCommand(command, origin);
+
+	return Empty;
+}
+
+void ApiEvents::CheckPeriodChangedHandler(const Checkable::Ptr& checkable, const TimePeriod::Ptr& timeperiod, const MessageOrigin& origin)
+{
+	ApiListener::Ptr listener = ApiListener::GetInstance();
+
+	if (!listener)
+		return;
+
+	Host::Ptr host;
+	Service::Ptr service;
+	tie(host, service) = GetHostService(checkable);
+
+	Dictionary::Ptr params = make_shared<Dictionary>();
+	params->Set("host", host->GetName());
+	if (service)
+		params->Set("service", service->GetShortName());
+	params->Set("timeperiod", timeperiod->GetName());
+
+	Dictionary::Ptr message = make_shared<Dictionary>();
+	message->Set("jsonrpc", "2.0");
+	message->Set("method", "event::SetCheckPeriod");
+	message->Set("params", params);
+
+	listener->RelayMessage(origin, checkable, message, true);
+}
+
+Value ApiEvents::CheckPeriodChangedAPIHandler(const MessageOrigin& origin, const Dictionary::Ptr& params)
+{
+	if (!params)
+		return Empty;
+
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
+
+	if (!host)
+		return Empty;
+
+	Checkable::Ptr checkable;
+
+	if (params->Contains("service"))
+		checkable = host->GetServiceByShortName(params->Get("service"));
+	else
+		checkable = host;
+
+	if (!checkable)
+		return Empty;
+
+	if (origin.FromZone && !origin.FromZone->CanAccessObject(checkable))
+		return Empty;
+
+	TimePeriod::Ptr timeperiod = TimePeriod::GetByName(params->Get("timeperiod"));
+
+	if (!timeperiod)
+		return Empty;
+
+	checkable->SetCheckPeriod(timeperiod, origin);
+
+	return Empty;
+}
+
+void ApiEvents::VarsChangedHandler(const CustomVarObject::Ptr& object, const Dictionary::Ptr& vars, const MessageOrigin& origin)
+{
+	ApiListener::Ptr listener = ApiListener::GetInstance();
+
+	if (!listener)
+		return;
+
+	Dictionary::Ptr params = make_shared<Dictionary>();
+	params->Set("object", object->GetName());
+	params->Set("vars", Serialize(vars));
+
+	Dictionary::Ptr message = make_shared<Dictionary>();
+	message->Set("jsonrpc", "2.0");
+	message->Set("method", "event::SetVars");
+	message->Set("params", params);
+
+	listener->RelayMessage(origin, object, message, true);
+}
+
+Value ApiEvents::VarsChangedAPIHandler(const MessageOrigin& origin, const Dictionary::Ptr& params)
+{
+	if (!params)
+		return Empty;
+
+	String objectName = params->Get("object");
+
+	if (objectName.IsEmpty())
+		return Empty;
+
+	/* ugly, but there is no other way currently */
+	CustomVarObject::Ptr object = Host::GetByName(objectName);
+	if (!object)
+		object = Service::GetByName(objectName);
+	if (!object)
+		object = User::GetByName(objectName);
+	if (!object)
+		object = Service::GetByName(objectName);
+	if (!object)
+		object = EventCommand::GetByName(objectName);
+	if (!object)
+		object = CheckCommand::GetByName(objectName);
+	if (!object)
+		object = NotificationCommand::GetByName(objectName);
+	if (!object)
+		return Empty;
+
+	if (origin.FromZone && !origin.FromZone->CanAccessObject(object))
+		return Empty;
+
+	Dictionary::Ptr vars = Deserialize(params->Get("vars"), true);
+
+	if (!vars)
+		return Empty;
+
+	object->SetVars(vars, origin);
+
+	return Empty;
+}
+
 void ApiEvents::CommentAddedHandler(const Checkable::Ptr& checkable, const Comment::Ptr& comment, const MessageOrigin& origin)
 {
 	ApiListener::Ptr listener = ApiListener::GetInstance();
@@ -557,7 +1073,7 @@ void ApiEvents::CommentAddedHandler(const Checkable::Ptr& checkable, const Comme
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("comment", Serialize(comment));
@@ -575,7 +1091,7 @@ Value ApiEvents::CommentAddedAPIHandler(const MessageOrigin& origin, const Dicti
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -613,7 +1129,7 @@ void ApiEvents::CommentRemovedHandler(const Checkable::Ptr& checkable, const Com
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("id", comment->GetId());
@@ -631,7 +1147,7 @@ Value ApiEvents::CommentRemovedAPIHandler(const MessageOrigin& origin, const Dic
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -666,7 +1182,7 @@ void ApiEvents::DowntimeAddedHandler(const Checkable::Ptr& checkable, const Down
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("downtime", Serialize(downtime));
@@ -684,7 +1200,7 @@ Value ApiEvents::DowntimeAddedAPIHandler(const MessageOrigin& origin, const Dict
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -725,7 +1241,7 @@ void ApiEvents::DowntimeRemovedHandler(const Checkable::Ptr& checkable, const Do
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("id", downtime->GetId());
@@ -743,7 +1259,7 @@ Value ApiEvents::DowntimeRemovedAPIHandler(const MessageOrigin& origin, const Di
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -780,7 +1296,7 @@ void ApiEvents::AcknowledgementSetHandler(const Checkable::Ptr& checkable,
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 	params->Set("author", author);
@@ -801,7 +1317,7 @@ Value ApiEvents::AcknowledgementSetAPIHandler(const MessageOrigin& origin, const
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -838,7 +1354,7 @@ void ApiEvents::AcknowledgementClearedHandler(const Checkable::Ptr& checkable, c
 	tie(host, service) = GetHostService(checkable);
 
 	Dictionary::Ptr params = make_shared<Dictionary>();
-	params->Set("host", GetVirtualHostName(host));
+	params->Set("host", host->GetName());
 	if (service)
 		params->Set("service", service->GetShortName());
 
@@ -855,7 +1371,7 @@ Value ApiEvents::AcknowledgementClearedAPIHandler(const MessageOrigin& origin, c
 	if (!params)
 		return Empty;
 
-	Host::Ptr host = FindHostByVirtualName(params->Get("host"));
+	Host::Ptr host = FindHostByVirtualName(params->Get("host"), origin);
 
 	if (!host)
 		return Empty;
@@ -887,14 +1403,14 @@ void ApiEvents::RepositoryTimerHandler(void)
 
 	Dictionary::Ptr repository = make_shared<Dictionary>();
 
-	BOOST_FOREACH(const Host::Ptr& host, DynamicType::GetObjects<Host>()) {
+	BOOST_FOREACH(const Host::Ptr& host, DynamicType::GetObjectsByType<Host>()) {
 		Array::Ptr services = make_shared<Array>();
 
 		BOOST_FOREACH(const Service::Ptr& service, host->GetServices()) {
 			services->Add(service->GetShortName());
 		}
 
-		repository->Set(GetVirtualHostName(host), services);
+		repository->Set(host->GetName(), services);
 	}
 
 	Endpoint::Ptr my_endpoint = Endpoint::GetLocalEndpoint();
@@ -935,6 +1451,18 @@ Value ApiEvents::UpdateRepositoryAPIHandler(const MessageOrigin& origin, const D
 	if (!params)
 		return Empty;
 
+	Value vrepository = params->Get("repository");
+	if (vrepository.IsEmpty() || !vrepository.IsObjectType<Dictionary>())
+		return Empty;
+
+	Dictionary::Ptr repository = vrepository;
+	Value hostInfo = repository->Get("localhost");
+
+	if (!hostInfo.IsEmpty() && origin.FromZone) {
+		repository->Remove("localhost");
+		repository->Set(origin.FromZone->GetName(), hostInfo);
+	}
+
 	String repositoryFile = GetRepositoryDir() + SHA256(params->Get("endpoint"));
 	String repositoryTempFile = repositoryFile + ".tmp";
 
@@ -968,30 +1496,16 @@ Value ApiEvents::UpdateRepositoryAPIHandler(const MessageOrigin& origin, const D
 	return Empty;
 }
 
-String ApiEvents::GetVirtualHostName(const Host::Ptr& host)
+Host::Ptr ApiEvents::FindHostByVirtualName(const String& hostName, const MessageOrigin& origin)
 {
-	String host_name = host->GetName();
-	if (host_name == "localhost") {
-		Endpoint::Ptr local = Endpoint::GetLocalEndpoint();
+	if (origin.FromZone) {
+		Zone::Ptr my_zone = Zone::GetLocalZone();
 
-		if (!local)
-			return Empty;
-
-		host_name = local->GetName();
+		if (origin.FromZone->IsChildOf(my_zone) && hostName == "localhost")
+			return Host::GetByName(origin.FromZone->GetName());
+		else if (!origin.FromZone->IsChildOf(my_zone) && hostName == my_zone->GetName())
+			return Host::GetByName("localhost");
 	}
 
-	return host_name;
-}
-
-Host::Ptr ApiEvents::FindHostByVirtualName(const String& hostName)
-{
-	Endpoint::Ptr local = Endpoint::GetLocalEndpoint();
-
-	if (!local)
-		return Host::Ptr();
-
-	if (hostName == local->GetName())
-		return Host::GetByName("localhost");
-	else
-		return Host::GetByName(hostName);
+	return Host::GetByName(hostName);
 }
