@@ -234,11 +234,11 @@ void Checkable::RemoveExpiredComments(void)
 
 void Checkable::CommentsExpireTimerHandler(void)
 {
-	BOOST_FOREACH(const Host::Ptr& host, DynamicType::GetObjects<Host>()) {
+	BOOST_FOREACH(const Host::Ptr& host, DynamicType::GetObjectsByType<Host>()) {
 		host->RemoveExpiredComments();
 	}
 
-	BOOST_FOREACH(const Service::Ptr& service, DynamicType::GetObjects<Service>()) {
+	BOOST_FOREACH(const Service::Ptr& service, DynamicType::GetObjectsByType<Service>()) {
 		service->RemoveExpiredComments();
 	}
 }
