@@ -24,6 +24,7 @@
 #include "base/dynamictype.hpp"
 #include "base/utility.hpp"
 #include "base/exception.hpp"
+#include "base/convert.hpp"
 #include <boost/foreach.hpp>
 
 using namespace icinga;
@@ -37,7 +38,7 @@ void Endpoint::OnConfigLoaded(void)
 {
 	DynamicObject::OnConfigLoaded();
 
-	BOOST_FOREACH(const Zone::Ptr& zone, DynamicType::GetObjects<Zone>()) {
+	BOOST_FOREACH(const Zone::Ptr& zone, DynamicType::GetObjectsByType<Zone>()) {
 		const std::set<Endpoint::Ptr> members = zone->GetEndpoints();
 
 		if (members.empty())
@@ -79,6 +80,8 @@ void Endpoint::RemoveClient(const ApiClient::Ptr& client)
 	{
 		boost::mutex::scoped_lock lock(m_ClientsLock);
 		m_Clients.erase(client);
+
+		Log(LogWarning, "ApiListener", "Removing API client for endpoint '" + GetName() + "'. " + Convert::ToString(m_Clients.size()) + " API clients left.");
 	}
 
 	bool is_master = ApiListener::GetInstance()->IsMaster();
